# Note: this file has been initially generated by Module::Build::Convert 0.50

use strict;
use warnings;

use Module::Build;

# See lib/ExtUtils/MakeMaker.pm for details of how to influence
# the contents of the Makefile that is written.

my $build = Module::Build->new
   (
    module_name => 'Test::Tail::Multi',
    dist_version_from => 'lib/Test/Tail/Multi.pm', # finds $VERSION\
    config_requires => { 'Module::Build' => 0 },
    requires => {
                  'File::Tail' => 0,
                  'Test::Simple' => '0.98', # e.g., Module::Name => 1.1
                },
    license => 'unknown',
    create_readme => 1,
    create_makefile_pl => 'traditional',
   );

$build->create_build_script;
